@@ -1,4 +1,4 @@
-def count_primes(self, n):
+def count_primes(n):
     if n < 2:
         return 0
     strikes = [1] * n
